@@ -98,6 +98,8 @@ class App:
         self.logger = logger
 
     async def __call__(self, scope, receive, send):
+        self.scope = scope
+
         await self.middleware(scope, receive, send)
 
     async def handle_request(self, request):
@@ -146,8 +148,15 @@ class App:
 
         self.routes[path] = handler
 
-    def add_middleware(self, middleware_cls):
-        self.middleware.add(middleware_cls)
+    def init_app(self):
+
+        def wrapper(handler):
+            self.init_app_functions.append(handler)
+
+        return wrapper
+
+    def add_middleware(self, middleware_cls, **kwargs):
+        self.middleware.add(middleware_cls, kwargs)
 
     def to_seconds(self, time: int, type) -> int:
         if type.lower() not in ["hour", "minute"]:
